SeaIceModes <- function(var, exp, obs, sdates, seasoninf = 6, seasonsup = 8, nclusters = 4, nleadtime = NULL, nmember = NULL, leadtimemin = 1, leadtimemax = NULL, storefreq = "monthly", sampleperiod = 1) {
  #
  # This function computes sea ice modes of variability based on the k-mean
  # method applied to sea ice area or extent averages over the Arctic Seas.
  #
  # Args:
  #   var can be sia or sie (sea ice area or extent)
  #   exp, obs, sdates, nleadtime, nmember, leadtimemin, leadtimemax, 
  #            storefreq are sampleperiod are the same as in Load;
  #            only exp, obs and sdates are compulsory
  #   seasoninf is the month of the year month when to start computing the 
  #            extended seasonal means: 1 to 12.
  #   seasonsup is the month of the year when to stop computing the extended
  #            seasonal means: 1 to 12. The extended seasonal means can overlap
  #            the 31s December: DJF average for example.
  #   nclusters : number of clusters to be computed
  #
  # Return:
  #   clusters : 3-dimensional matrice (x, y, nclusters) containing the
  #              centroides  
  #   pvalue   : 3-dimensional matrice (x, y, nclusters) containing the
  #              pvalue of the centroide anomalies obtained through a t-test
  #              that accounts for the serial dependence of the data
  #   occurrences : 2-dimension matrice (nclusters, time) containing 1 (when
  #                 a given cluster occurs) or 0 (when it does not occur)
  #
  # History:
  #
###############################################################################

# For the loading stage, you should define listseas :
# listseas=c('Kara_Sea', 'Laptev_Sea' ... )
# then you can loop : for (sea in listseas) { ...
# call Load : tmp = Load(paste(var,sea,sep='_') , 
#             and all the other arguments passed to SeaIceeModes
# call Season over tmp and passing seasoninf and seasonsup
# then if (listseas[1] == sea) { bubi=array(dim=c(length(lstseas,length(tmp)[4])) }
# then fill bubi with the ensemble mean of tmp2
# end of the loop over the seas to fill bubi 


# Once you have recoded the lines above and you have made a few tests on the 
# computation of clusters, you can work on adding the step of computing
# the weights to be sent to Cluster at this location of the function. For now,
# I have set weights to 1 as a default so that they don't bother you for the
# first tests.

# Then here, you send bubi to the Cluster function
# You obtain the array of occurrences that you can use to composite the sea ice
# concentration to obtain clusters with dimensions (x, y, time). To do so,
# you need to call Load('sic', wil all the arguments used when loading the area
# averages)
#
# Then you call the function Composite to obtain the clusters on the (x,y,time)
# grid and their pvalue
#

}
